@@ -1,7 +1,7 @@
 package App::lcpan::Cmd::mod2dist;
 
 our $DATE = '2016-02-17'; # DATE
-our $VERSION = '0.77'; # VERSION
+our $VERSION = '0.78'; # VERSION
 
 use 5.010;
 use strict;
@@ -13,7 +13,7 @@ our %SPEC;
 
 $SPEC{'handle_cmd'} = {
     v => 1.1,
-    summary => 'Get distribution name of a module',
+    summary => 'Get distribution name of module(s)',
     args => {
         %App::lcpan::common_args,
         %App::lcpan::mods_args,
@@ -53,7 +53,7 @@ WHERE module.name IN ($mods_s)");
 }
 
 1;
-# ABSTRACT: Get distribution name of a module
+# ABSTRACT: Get distribution name of module(s)
 
 __END__
 
@@ -63,18 +63,18 @@ __END__
 
 =head1 NAME
 
-App::lcpan::Cmd::mod2dist - Get distribution name of a module
+App::lcpan::Cmd::mod2dist - Get distribution name of module(s)
 
 =head1 VERSION
 
-This document describes version 0.77 of App::lcpan::Cmd::mod2dist (from Perl distribution App-lcpan), released on 2016-02-17.
+This document describes version 0.78 of App::lcpan::Cmd::mod2dist (from Perl distribution App-lcpan), released on 2016-02-17.
 
 =head1 FUNCTIONS
 
 
 =head2 handle_cmd(%args) -> [status, msg, result, meta]
 
-Get distribution name of a module.
+Get distribution name of module(s).
 
 This function is not exportable.
 
